@@ -32,6 +32,11 @@ Material::Material(Color bg, Color fg)
   line_antialias(false),
   depth_mask(true),
   depth_test(1),  // "less"
+  textype(Texture::RGB),    
+  mipmap(false),
+  minfilter(1),
+  magfilter(1),
+  envmap(false),
   glVersion(-1.0)
 {
   alphablend = ( ( bg.getAlphaf() < 1.0f ) || ( fg.getAlphaf() < 1.0f ) ) ? true : false;
