@@ -4,8 +4,9 @@
 // $Id: win32gui.hpp 840 2012-01-06 16:07:37Z murdoch $
 // ---------------------------------------------------------------------------
 #include "gui.hpp"
-// ---------------------------------------------------------------------------
-namespace gui {
+
+namespace rgl {
+
 // ---------------------------------------------------------------------------
 class NULLGUIFactory : public GUIFactory
 {
@@ -15,7 +16,8 @@ public:
   WindowImpl* createWindowImpl(Window* window);
 };
 // ---------------------------------------------------------------------------
-} // namespace gui
-// ---------------------------------------------------------------------------
+
+} // namespace rgl
+
 #endif // RGL_NULL_GUI_HPP
 
