@@ -1,6 +1,8 @@
 
 #include "Texture.hpp"
 #include "pixmap.h"
+#include "config.hpp"
+#include "platform.h"
 
 using namespace std;
 using namespace rgl;
@@ -115,6 +117,7 @@ void Texture::getParameters(Type *out_type, bool *out_mipmap,
   strncpy(out_filename, filename, buflen);
 }
 
+#ifndef MODERN_OPENGL
 static unsigned int texsize(unsigned int s)
 {
   return 1U << msb(s-1);
@@ -130,6 +133,7 @@ static void printGluErrorMessage(GLint error)
   sprintf(buf, "GLU Library Error : %s", (const char*) gluError);
   printMessage(buf);
 }
+#endif
 
 void Texture::init(RenderContext* renderContext)
 {
@@ -206,8 +210,13 @@ void Texture::init(RenderContext* renderContext)
   
   GLint glTexSize;
   glGetIntegerv(GL_MAX_TEXTURE_SIZE,  &glTexSize );        
-  unsigned int maxSize = static_cast<unsigned int>(glTexSize);
   
+  #ifdef MODERN_OPENGL
+  glTexImage2D(GL_TEXTURE_2D, 0, internalFormat, pixmap->width, pixmap->height, 0, format, gl_type , pixmap->data);
+  if (mipmap)
+    glGenerateMipmap(GL_TEXTURE_2D);
+  #else
+  unsigned int maxSize = static_cast<unsigned int>(glTexSize);
   if (mipmap) {                  
     int gluError = gluBuild2DMipmaps(GL_TEXTURE_2D, internalFormat, pixmap->width, pixmap->height, format, gl_type, pixmap->data);    
     if (gluError)
@@ -231,7 +240,8 @@ void Texture::init(RenderContext* renderContext)
       glTexImage2D(GL_TEXTURE_2D, 0, internalFormat, pixmap->width, pixmap->height, 0, format, gl_type , pixmap->data);
     }
   }
-
+  #endif /* not MODERN_OPENGL */
+  
   if (envmap) {
     glTexGeni(GL_S, GL_TEXTURE_GEN_MODE, GL_SPHERE_MAP);
     glTexGeni(GL_T, GL_TEXTURE_GEN_MODE, GL_SPHERE_MAP);
